@@ -26,6 +26,7 @@ function(u, alpha_0, beta_0, alpha.post.i, beta.post.i,
 				v2 <- dbeta(qbeta(u,shape1 = alpha_0, shape2 = beta_0), 
 						shape1 = alpha_0, shape2 = beta_0)
 				ratio <- v1/v2
+				ratio[is.na(ratio)]<-0 #handles cases where first and last of both are 0
 				return(ratio)
 			}
 		 },
@@ -39,6 +40,7 @@ function(u, alpha_0, beta_0, alpha.post.i, beta.post.i,
 				v2 <- dgamma(qgamma(u, shape = alpha_0, scale = beta_0), 
 						shape = alpha_0, scale = beta_0)
 				ratio <- v1/v2
+				ratio[is.na(ratio)]<-0
 				return(ratio)
 			}
 		 }
